<template>
  <div class="rightContent">
    <div class="top">
      <SearchCommonView
        :add-title="'新建'"
        :placeholder="'请输入仓库'"
        :amount-view="false"
        @addCommonClick="addBtnClick"
        @searchClick="getList"
      />
    </div>
    <div class="list-view">
      <div class="table">
        <TableCommonView
          ref="tableListRef"
          :table-list="tableList"
          :show-checkcol="false"
        >
        <template slot="tableButton">
            <el-table-column label="操作" width="120" fixed="right">
              <template slot-scope="scope">
                <el-button
                  @click="tableRowClick(scope.row,'edit')"
                  type="text"
                  size="small"
                  >编辑</el-button
                >
                <el-button
                  type="text"
                  size="small"
                  @click="tableRowClick(scope.row,'look')"
                  >查看</el-button
                >
              </template>
            </el-table-column>
          </template>
      </TableCommonView>
      </div>
      <div class="btn-pager">
        <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
      </div>
    </div>
    <!-- 新建/编辑 -->
    <AddDialog v-if="editConfig.visible" @refresh="refresh" :edit-common-config="editConfig" />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import { getWarehouseList } from "@/api/warehouseManage/warehouse"
import AddDialog from "@/views/warehouseManage/warehouse/AddDialog"

export default {
  name: "WarehouseView",
  props: {},
  components: { AddDialog },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {},
      keyword:'',
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      }
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [],
        selectBox: false,
        selectIndex: true,
        showcol: this.showcol,
        allcol: [],
        tableColumn: this.setTableColumn(this.showcol)
      }
      let allcol = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        if (!this.tableList.tableColumn[i].default) {
          const label = this.tableList.tableColumn[i].label
          allcol.push(label)
        }
      }
      this.tableList.allcol = allcol
    },
    setTableColumn(showcol) {
      console.log(showcol)
      let tableColumn = [
        {
          label: "仓库",
          prop: "name",
          isShowColumn: true,
          default: true
        },
        {
          label: "库存位置",
          prop: "warehouseLocation",
          isShowColumn: true,
          default: true
        },
        {
          label: "地址",
          prop: "address",
          isShowColumn: true,
          default: true
        }
      ]
      return tableColumn
    },
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setTableColumn(val)
    },
    // 请求数据
    async getData() {
      await getWarehouseList({
        keyword: this.keyword,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      }).then((res) => {
        if (res.data.code == 200) {
          const list = res.data.data?res.data.data:[]
          this.tableList.tableInfomation = list
          this.pagerOptions.totalCount = res.data.total
        }
      })
    },
    refresh(){
      this.pagerOptions.currPage=1
      this.getData()
    },
    // 搜索
    getList(val) {
      this.keyword=val;
      this.pagerOptions.currPage=1
      this.getData()
    },
    // 行点击
    tableRowClick(row,val) {
      this.editConfig.title = val=='look'?'查看':"编辑"
      this.editConfig.infomation = { ...row }
      this.editConfig.visible = true
    },
    // 新建
    addBtnClick() {
      this.editConfig.infomation={
        address:'',
        buyToResupply:null,
        code:'',
        name:'',
        inboundTransportation:1,
        outboundTransportation:1,
      }
      this.editConfig.visible = true
      this.editConfig.title = "新建"
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped></style>
